.. highlight:: shell

===============
Getting Started
===============


Installation
------------

Stable release
++++++++++++++

To install Poisson Approval, run this command in your terminal:

.. code-block:: console

    $ pip install poisson_approval

This is the preferred method to install Poisson Approval, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
++++++++++++

The sources for Poisson Approval can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/francois-durand/poisson_approval

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://github.com/francois-durand/poisson_approval/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/francois-durand/poisson_approval
.. _tarball: https://github.com/francois-durand/poisson_approval/tarball/master


Usage
-----

To use Poisson Approval in a project::

    import poisson_approval
